@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2012 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2009, 2012-2013 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -14,9 +14,8 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import inspect
-
-from import_relative import *
+import os
+from import_relative import import_relative
 # Our local modules
 Mbase_subcmd  = import_relative('base_subcmd', os.path.pardir)
 
