@@ -13,7 +13,7 @@
 #
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-import re, sys, threading
+import sys, threading
 
 from import_relative import import_relative
 # Our local modules
