@@ -18,9 +18,7 @@ import os
 from import_relative import import_relative
 
 # Our local modules
-import_relative('lib', '....pydbgr')
-import_relative('processor', '....pydbgr')
-base_cmd   = import_relative('base_cmd')
+base_cmd   = import_relative('base_cmd', top_name='pydbgr')
 Mcmdfns    = import_relative('cmdfns', '..', 'pydbgr')
 Mstack     = import_relative('stack',  '...lib', 'pydbgr')
 
