@@ -16,8 +16,8 @@
 
 from import_relative import import_relative
 # Our local modules
-import_relative('lib', '....', 'pydbgr')
-import_relative('processor', '....', 'pydbgr')
+import_relative('lib', '....')
+import_relative('processor', '....')
 
 Mbase_subcmd = import_relative('base_subcmd', '..', 'pydbgr')
 Mcmdfns      = import_relative('cmdfns', '...', 'pydbgr')
@@ -54,10 +54,7 @@ class SetAutoList(Mbase_subcmd.DebuggerSetBoolSubcommand):
     pass
 
 if __name__ == '__main__':
-    mock = import_relative('mock', '..')
-    Mset = import_relative('set', '..')
-    d, cp = mock.dbg_setup()
-    s = Mset.SetCommand(cp)
-    sub = SetAutoList(s)
+    Mhelper = import_relative('__demo_helper__', '.', 'pydbgr')
+    Mhelper.demo_run(SetAutoList)
     pass
 
