@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2010 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2009-2010, 2013 Rocky Bernstein rocky@gnu.org
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -14,11 +14,9 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import tracer
-from import_relative import *
+from import_relative import import_relative
 Mbase_subcmd  = import_relative('base_subcmd', '..', 'pydbgr')
 
-
 class SetTrace(Mbase_subcmd.DebuggerSetBoolSubcommand):
 
     """Set event tracing.
@@ -32,14 +30,11 @@ See also "set events","set trace", and "show trace".
     pass
 
 if __name__ == '__main__':
-    mock = import_relative('mock', '..')
-    Mset = import_relative('set', '..')
-    d, cp = mock.dbg_setup()
-    s = Mset.SetCommand(cp)
-    sub = SetTrace(s)
-    sub.name = 'trace'
+    Mhelper = import_relative('__demo_helper__', '.', 'pydbgr')
+    sub = Mhelper.demo_run(SetTrace)
+    d = sub.proc.debugger
     for args in (['on'], ['off']):
         sub.run(args)
-        print d.settings['trace']
+        print(d.settings['trace'])
         pass
     pass
