@@ -18,6 +18,18 @@ from import_relative import import_relative
 Mbase_subcmd  = import_relative('base_subcmd', '..', 'pydbgr')
 
 class ShowAutoPython(Mbase_subcmd.DebuggerShowBoolSubcommand):
-    """Show automatic Python when we enter the debugger."""
+    '''**show autopython**
+
+Show whether we go into a python shell when automatically when the
+debugger is entered.
+
+Change with **set autopython**
+'''
+    short_help = "Show automatic Python shell entry"
     min_abbrev = len('autopy')
     pass
+
+if __name__ == '__main__':
+    Mhelper = import_relative('__demo_helper__', '.', 'pydbgr')
+    mgr = Mhelper.demo_run(ShowAutoPython)
+    pass
