@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#  Copyright (C) 2009 Rocky Bernstein
+#  Copyright (C) 2009, 2013 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,18 @@ from import_relative import import_relative
 Mbase_subcmd  = import_relative('base_subcmd', '..', 'pydbgr')
 
 class ShowBasename(Mbase_subcmd.DebuggerShowBoolSubcommand):
-    """Show the basename portion only of filenames."""
-    min_abbrev = len('ba') 
+    '''**show basename**
+
+Show whether filenames are reported with just the basename or the
+fully qualified filename.
+
+Change with **set basename**
+'''
+    short_help = "Show the basename portion only of filenames"
+    min_abbrev = len('ba')
     pass
 
-
+if __name__ == '__main__':
+    Mhelper = import_relative('__demo_helper__', '.', 'pydbgr')
+    Mhelper.demo_run(ShowBasename)
+    pass
