@@ -19,9 +19,6 @@
 from import_relative import *
 # Our local modules
 
-# FIXME: Until import_relative is fixed up...
-import_relative('processor', '....', 'pydbgr')
-
 Mbase_subcmd = import_relative('base_subcmd', os.path.pardir, 'pydbgr')
 Mcmdfns      = import_relative('cmdfns', '...', 'pydbgr')
 class ShowEvents(Mbase_subcmd.DebuggerSubcommand):
