@@ -13,12 +13,12 @@ import sys
 def check_args():
     if len(sys.argv) != 3:
         # Rather than use sys.exit let's just raise an error
-        raise Exception, "Need to give two numbers"
+        raise Exception("Need to give two numbers")
     for i in range(2):
         try: 
             sys.argv[i+1] = int(sys.argv[i+1])
         except ValueError:
-            print "** Expecting an integer, got: %s" % repr(sys.argv[i])
+            print("** Expecting an integer, got: %s" % repr(sys.argv[i]))
             sys.exit(2)
             pass
         pass
@@ -41,6 +41,6 @@ if __name__=='__main__':
     check_args()
 
     (a, b) = sys.argv[1:3]
-    print "The GCD of %d and %d is %d" % (a, b, gcd(a, b))
+    print("The GCD of %d and %d is %d" % (a, b, gcd(a, b)))
     pass
 
