@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-import os, sys, unittest
+import unittest
 from fn_helper import *
 
-class TestNext(unittest.TestCase):
+class TestFinish(unittest.TestCase):
     def test_finish_same_level(self):
-        print "test ", __file__, "finish_same_level skipped"
+        print("test ", __file__, "finish_same_level skipped")
         return
 
         cmds = ['step 5', 'finish', 'continue']
