@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-import os, sys, unittest
-import tracer
+import unittest
 from fn_helper import *
 
 class TestSkip(unittest.TestCase):
@@ -22,7 +21,7 @@ class TestSkip(unittest.TestCase):
         self.assertEqual(5, x)  # Make sure lines were skipped.
 
         # See that we can skip with a count value
-        print "skipping second skip test"
+        print("skipping second skip test")
         return
         cmds = ['skip 2', 'continue']
         d = strarray_setup(cmds)
