@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 'Unit test for the debugger lib breakpoint'
-import operator, os, re, sys, unittest
-from import_relative import *
+import re, unittest
+from import_relative import import_relative
 
 Mbreakpoint = import_relative('lib.breakpoint', '...pydbgr')
 
