@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 'Unit test for pydbgr.io.input'
-import operator, os, sys, unittest
-from import_relative import *
+import os, unittest
+from import_relative import import_relative, get_srcdir
 
-Minput = import_relative('io.input', '...pydbgr')
+Minput = import_relative('pydbgr.io.input', '...')
 
 class TestDebuggerInput(unittest.TestCase):
     
