@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 'Unit test for pydbgr.processor.command.quit'
-import inspect, os, sys, unittest
+import unittest
 
-from import_relative import *
+from import_relative import import_relative
 
 Mquit = import_relative('processor.command.quit', '...pydbgr')
 
@@ -11,10 +11,6 @@ from cmdhelper import dbg_setup
 class TestQuit(unittest.TestCase):
     """Tests QuitCommand class"""
 
-    def setUp(self):
-        self.signal_caught = False
-        return
-
     def test_quit(self):
         """Test processor.command.quit.QuitCommand.run()"""
         d, cp = dbg_setup()
