@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 'Unit test for pydbgr.io.tcp*'
-import inspect, os, sys, unittest
+import unittest
 
-from import_relative import *
+from import_relative import import_relative
 import_relative('io', '...pydbgr', 'pydbgr')
 Mserver   = import_relative('io.tcpserver', '...pydbgr', 'pydbgr')
 Mclient   = import_relative('io.tcpclient', '...pydbgr', 'pydbgr')
@@ -20,17 +20,18 @@ class TestTCP(unittest.TestCase):
             return
         try:
             client = Mclient.TCPClient(opts={'open': True})
-            for line in ['one', 'two', 'three']: 
+            for line in ['one', 'two', 'three']:
                 server.writeline(line)
                 self.assertEqual(line, client.read_msg().rstrip('\n'))
                 pass
-            for line in ['four', 'five', 'six']: 
+            for line in ['four', 'five', 'six']:
                 client.writeline(line)
                 self.assertEqual(line, server.read_msg().rstrip('\n'))
                 pass
         except:
             print("Skipping because of client open failure")
-            return
+            pass
+        server.close()
         return
 
 if __name__ == '__main__':
